@@ -5,6 +5,7 @@ import time
 from pathlib import Path
 from typing import Union, Optional, Callable, List, Dict, Any
 
+import depthai
 import depthai as dai
 import robothub
 from depthai_sdk import OakCamera, CameraComponent, StereoComponent, NNComponent
@@ -148,6 +149,9 @@ class HubCamera:
         self.oak_camera.device.close()
 
     def stats_report(self) -> Dict[str, Any]:
+        """
+        Returns a dictionary with statistics about the device.
+        """
         stats = {'mxid': self.device.getMxId()}
 
         css_cpu_usage = self.device.getLeonCssCpuUsage().average
@@ -171,7 +175,9 @@ class HubCamera:
         return stats
 
     def info_report(self) -> Dict[str, Any]:
-        """Returns device info"""
+        """
+        Returns a dictionary with information about the device.
+        """
         info = {
             'mxid': self.device.getMxId(),
             'protocol': 'unknown',
@@ -180,6 +186,7 @@ class HubCamera:
             'board_name': 'unknown',
             'board_rev': 'unknown',
             'bootloader_version': 'unknown',
+            'state': self.state.value,
         }
 
         device_info = try_or_default(self.device.getDeviceInfo)
@@ -234,7 +241,6 @@ class HubCamera:
     def _get_sensor_names(self) -> List[str]:
         """
         Returns a list of available sensors on the device.
-
         :return: List of available sensors.
         """
         self._connect()
@@ -252,3 +258,43 @@ class HubCamera:
         Returns the device object.
         """
         return self.oak_camera.device
+
+    @property
+    def is_connected(self) -> bool:
+        """
+        Returns whether the device is connected or not.
+        :return: True if connected, False otherwise.
+        """
+        return not self.device.isClosed()
+
+    @property
+    def has_color(self) -> bool:
+        """
+        Returns whether the device has a color camera.
+        :return: True if the device has a color camera, False otherwise.
+        """
+        return depthai.CameraBoardSocket.RGB in self.available_sensors
+
+    @property
+    def has_left(self) -> bool:
+        """
+        Returns whether the device has a left camera.
+        :return: True if the device has a left camera, False otherwise.
+        """
+        return depthai.CameraBoardSocket.LEFT in self.available_sensors
+
+    @property
+    def has_right(self) -> bool:
+        """
+        Returns whether the device has a right camera.
+        :return: True if the device has a right camera, False otherwise.
+        """
+        return depthai.CameraBoardSocket.RIGHT in self.available_sensors
+
+    @property
+    def has_stereo(self) -> bool:
+        """
+        Returns whether the device has a depth camera.
+        :return: True if the device has a stereo camera, False otherwise.
+        """
+        return self.has_left and self.has_right
